﻿local backdrop = {
	bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 16,
	edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", edgeSize = 16,
	insets = {left = 4, right = 4, top = 4, bottom = 4},
}

local gradientOn = {"VERTICAL", .1, .1, .1, 0, .25, .25, .25, 1}
local gradientOff = {"VERTICAL", 0, 0, 0, 1, 0, 0, 0, 1}

local sdb = {
	BackdropBorder = {r = 0.5, g = 0.5, b = 0.5, a = 1},
	Backdrop = {r = 0, g = 0, b = 0, a = 0.9},
	FadeHeight = {enable = false, value = 500, force = false},
	Gradient = true,
}

local LM = CreateFrame("Frame", "LootMon_Frame")
	LM:SetScript("OnEvent", function(self, event, arg1) self[event](self, event, arg1) end)
	LM:RegisterEvent("CHAT_MSG_LOOT")
	LM:RegisterEvent("CHAT_MSG_MONEY")
	LM:RegisterEvent("ADDON_LOADED")
local deformat = LibStub("LibDeformat-3.0")
	LM.items = {}
	LM.id = 0
local items, id = LM.items, LM.id
local ADDON_NAME, ns = ...

------------------------------
------- Config ---------------
------------------------------

local LootMonDB_default = {}
local config 

LootMonDB_default = {
	selfRarity = 0, --0 = Poor, 1 = Common, 2 = Uncommon, 3 = Rare, 4 = Epic, 5 = Legendary, 6 = Artifact, 7 = Heirloom
	Rarity = 2,
	position = {
		Xoff = 5,
		Yoff = 150,
		Anchor = "UIParent", 
		AnchorPoint = "LEFT", 
		nextFrameOff = 25,
	},
	scale = 1.0,
	maxItems = 10,
	timers = {
		fadeIn = 1, -- time to show item
		fadeOut = 1, -- time to hide item
		fade = 10, --how long item is shown
	},
}

local function createConfigFrame() 
	local rarityList = {
		[0] = "Poor",
		[1] = "Common",
		[2] = "Uncommon",
		[3] = "Rare",
		[4] = "Epic",
		[5] = "Legendary",
		[6] = "Artifact",
		[7] = "Heirloom",
	}
	
	local AnchorPointList = {
		["LEFT"] = "LEFT",
		["RIGHT"] = "RIGHT",
	}
	
	local floor, format, unpack = math.floor, string.format, unpack
	local CreateOptionsPanel = LibStub("PhanxConfig-OptionsPanel").CreateOptionsPanel

local optionsPanel = CreateOptionsPanel(ADDON_NAME, nil, function(self)
	
	local CreateSlider = LibStub("PhanxConfig-EditBox").CreateSlider
	local CreatePanel = LibStub("PhanxConfig-Panel").CreatePanel
	local CreateCheckbox = LibStub("PhanxConfig-Checkbox").CreateCheckbox
	local CreateDropdown = LibStub("PhanxConfig-Dropdown").CreateDropdown
	local CreateSlider = LibStub("PhanxConfig-Slider").CreateSlider
	local title, notes = LibStub("PhanxConfig-Header").CreateHeader(self, ADDON_NAME, "Loot watcher")	
	local screenwidth = UIParent:GetWidth()
	local screenheight = UIParent:GetHeight()

	local scaleSlider = CreateSlider(self, "Scale", 0.1, 3, 0.05, true)
		scaleSlider.desc = "Adjust frames scale." 																		
		scaleSlider:SetPoint("TOPLEFT", notes, "BOTTOMLEFT", -4, -20)
		scaleSlider:SetPoint("TOPRIGHT", notes, "BOTTOM", -8, 20)
		scaleSlider.SetValue(scaleSlider, config.scale)
		scaleSlider.OnValueChanged = function(self, value) 
			config.scale = value 
		end
	
	StaticPopupDialogs["RELOAD"] = {
			text = "Need ReloadUI",
			OnAccept = function() 
			ReloadUI() 
		end,
		button1 = ACCEPT,
		timeout = 0,
		whileDead = 1,
		preferredIndex = 3,
	}
	
	local maxItemsSlider = CreateSlider(self, "Max Items", 1, 40, 1)
		maxItemsSlider.desc = "Total amount of displayed items"																	
		maxItemsSlider:SetPoint("TOPLEFT", notes, "BOTTOM", 2, -20)
		maxItemsSlider:SetPoint("TOPRIGHT", scaleSlider, "BOTTOMRIGHT", 300, -20)
		maxItemsSlider.SetValue(maxItemsSlider, config.maxItems)
		maxItemsSlider.OnValueChanged = function(self, value)
			config.maxItems = value
			StaticPopup_Show("RELOAD")
		end
	
	local timersFadeSlider = CreateSlider(self, "Fade Timer", 1, 60, 0.5)
		timersFadeSlider.desc = "How long item is shown"																
		timersFadeSlider:SetPoint("TOPLEFT", scaleSlider, "BOTTOMLEFT", 0, -20)
		timersFadeSlider:SetPoint("TOPRIGHT", scaleSlider, "BOTTOMRIGHT", -scaleSlider:GetWidth()/3-7, -20)
		timersFadeSlider.SetValue(timersFadeSlider, config.timers.fade)
		timersFadeSlider.OnValueChanged = function(self, value)
			config.timers.fade = value
		end
	
	local timersFadeInSlider = CreateSlider(self, "Fade In Timer", 1, 10, 0.1)
		timersFadeInSlider.desc = "Time to show item"															
		timersFadeInSlider:SetWidth(timersFadeSlider:GetWidth())
		timersFadeInSlider:SetPoint("LEFT", timersFadeSlider, "RIGHT", 14, 0)
		timersFadeInSlider.SetValue(timersFadeInSlider, config.timers.fadeIn)
		timersFadeInSlider.OnValueChanged = function(self, value)
			config.timers.fadeIn = value
		end

	local timersFadeOutSlider = CreateSlider(self, "Fade Out Timer", 1, 10, 0.1)
		timersFadeOutSlider.desc = "Time to hide item"
		timersFadeOutSlider:SetWidth(timersFadeSlider:GetWidth())
		timersFadeOutSlider:SetPoint("LEFT", timersFadeInSlider, "RIGHT", 14, 0)
		timersFadeOutSlider.SetValue(timersFadeOutSlider, config.timers.fadeOut)
		timersFadeOutSlider.OnValueChanged = function(self, value)
			config.timers.fadeOut = value
		end
	

	
	local posXSlider = CreateSlider(self, "X Offset", 0, floor(screenwidth / 10) / 2 * 10, 5)
		posXSlider.desc = "Adjust X offset"
		posXSlider:SetPoint("TOPLEFT", timersFadeSlider, "BOTTOMLEFT", 0, -20)
		posXSlider:SetPoint("TOPRIGHT", timersFadeSlider, "BOTTOMRIGHT", 0, -20)
		posXSlider.SetValue(posXSlider, config.position.Xoff)
		posXSlider.OnValueChanged = function(self, value)
			config.position.Xoff = value
		end

	local posYSlider = CreateSlider(self, "Y Offset", floor(screenheight / 10) / 2 * -10, floor(screenheight / 10) / 2 * 10, 5)
		posYSlider.desc = "Adjust Y offset"
		posYSlider:SetPoint("TOPLEFT", timersFadeInSlider, "BOTTOMLEFT", 0, -20)
		posYSlider:SetPoint("TOPRIGHT", timersFadeInSlider, "BOTTOMRIGHT", 0, -20)
		posYSlider.SetValue(posYSlider, config.position.Yoff)
		posYSlider.OnValueChanged = function(self, value)
			config.position.Yoff = value
		end	
	
	local posOffSlider = CreateSlider(self, "Spacing", 0, floor(screenheight/5), 5)
		posOffSlider.desc = "Adjust frame spacing"
		posOffSlider:SetPoint("TOPLEFT", timersFadeOutSlider, "BOTTOMLEFT", 0, -20)
		posOffSlider:SetPoint("TOPRIGHT", timersFadeOutSlider, "BOTTOMRIGHT", 0, -20)
		posOffSlider.SetValue(posOffSlider, config.position.nextFrameOff)
		posOffSlider.OnValueChanged = function(self, value)
			config.position.nextFrameOff = value
		end	

	local AnchorPoint
	do
		local function OnClick(self)
			AnchorPoint:SetValue(self.value, self.text)
			config.position.AnchorPoint = self.value
		end

		local info = { } 

		AnchorPoint = CreateDropdown(self, "Anchor Point", function()

			local selected = config.position.AnchorPoint

			info.text = "LEFT"
			info.value = "LEFT"
			info.func = OnClick
			info.checked = "LEFT" == selected
			UIDropDownMenu_AddButton(info)

			info.text = "RIGHT"
			info.value = "RIGHT"
			info.func = OnClick
			info.checked = "RIGHT" == selected
			UIDropDownMenu_AddButton(info)
		end)
	end
	AnchorPoint.desc = "Anchor Point"
	AnchorPoint:SetPoint("TOPLEFT", posXSlider, "BOTTOMLEFT", 0, -20)
	AnchorPoint:SetPoint("TOPRIGHT", posXSlider, "BOTTOMRIGHT", 0, -20)
	AnchorPoint:SetValue(config.position.AnchorPoint, AnchorPointList[config.position.AnchorPoint])
	
	local selfRarityDD
	do
		local function OnClick(self)
			selfRarityDD:SetValue(self.value, self.text)
			for i=0,7 do if rarityList[i] == self.value then config.selfRarity = i end end
		end
		selfRarityDD = CreateDropdown(self, "Self Rarity", function(self)
			local info = UIDropDownMenu_CreateInfo()
			local selected = rarityList[config.selfRarity]
			for k = 0, 7 do
				v= rarityList[k]
				info.text = v
				info.value = v
				info.func = OnClick
				info.checked = v == selected
				UIDropDownMenu_AddButton(info)
			end
		end)
	end
	selfRarityDD.desc = "Min quality for your looted items that will be displayed"
	selfRarityDD:SetPoint("TOPLEFT", posOffSlider, "BOTTOMLEFT", 0, -20)
	selfRarityDD:SetPoint("TOPRIGHT", posOffSlider, "BOTTOMRIGHT", 0, -20)
	selfRarityDD:SetValue(config.selfRarity, rarityList[config.selfRarity])
	
	local otherRarityDD
	do
		local function OnClick(self)
			otherRarityDD:SetValue(self.value, self.text)
			for i=0,7 do if rarityList[i] == self.value then config.Rarity = i end end
		end
		otherRarityDD = CreateDropdown(self, "Other Rarity", function(self)
			local info = UIDropDownMenu_CreateInfo()
			local selected = rarityList[config.Rarity]
			for k = 0, 7 do
				v= rarityList[k]
				info.text = v
				info.value = v
				info.func = OnClick
				info.checked = v == selected
				UIDropDownMenu_AddButton(info)
			end
		end)
	end
	otherRarityDD.desc = "Min quality for your party members looted items that will be displayed"
	otherRarityDD:SetPoint("TOPLEFT", posYSlider, "BOTTOMLEFT", 0, -20)
	otherRarityDD:SetPoint("TOPRIGHT", posYSlider, "BOTTOMRIGHT", 0, -20)
	otherRarityDD:SetValue(config.Rarity, rarityList[config.Rarity])
			
	StaticPopupDialogs["RESET_ALL"] = {
	text = "Reset all setting to default?",
	OnAccept = function() 
		LootMonDB = LootMonDB_default
		ReloadUI() 
	end,
	button1 = ACCEPT,
	button2 = CANCEL,
	timeout = 0,
	whileDead = 1,
	preferredIndex = 3,
	}

	local resetall = CreateFrame("Button", nil, selfRarityDD, "UIPanelButtonTemplate")
	resetall:SetSize(120, 25)
	resetall:SetText("Reset all")
	resetall:SetPoint("LEFT", AnchorPoint, "LEFT", 0, -245)
	resetall:SetScript("OnClick", function(self) 
		StaticPopup_Show("RESET_ALL")
	end)


end)

end

------------------------------
------- Config ---------------
------------------------------

local function debug(msg)
	SELECTED_DOCK_FRAME:AddMessage("LootMon Debug: "..msg)
	--print(msg or "nil")
end

--timer
local CreateTimer = function(duration, step, id) 
	
    if(not duration or duration <= 0) then 
        return
    end 
     
    if(not step or step <= 0) then 
        return
    end 
     
    local timer
	if not timer then timer = CreateFrame('Frame') end

    timer.duration = duration
    timer.step = step

    timer.timeleft = duration
    timer.nextUpdate = 0
	
    timer:SetScript('OnUpdate', function(self, elapsed) 
		if(timer.timeleft <= 0) then  
			timer:SetScript('OnUpdate',nil) 
			if(id) then 
				UIFrameFadeIn(items[id], config.timers.fadeOut, 1, 0) 
				items[id].fadeInfo.finishedFunc = function() 
					items[id]:Hide() 
					items[id].isshown = false 
				end
			end;  
		end 
         
		if(timer.nextUpdate <= 0) then  
			timer.nextUpdate = timer.nextUpdate - elapsed
			timer.timeleft = timer.timeleft - elapsed
		end 
		end)
    return timer
end  
------------------------------
------------------------------

local function unitFromPlayerName(name)
	name = string.gsub(name, "(-.*)", "")

	if UnitName("player") == name then 
		--debug("player")
		return "player" 
	end
	--[[if GetNumGroupMembers() == 0 then
		for i=1,GetNumPartyMembers() do
			if(UnitName("party"..i) == name) then
				return "party"..i
			end
		end
	else]]
	--[[debug(GetNumGroupMembers())
	
		for i=1,GetNumGroupMembers() do
			--debug(UnitName("group"..i))
			if(UnitName("party"..i) == name) then
			debug("party"..i)
				return "party"..i
			end
		end
	end--]]
	
	
	if UnitInRaid("player") then 
		for i=1,GetNumGroupMembers() do 
			if(UnitName("raid"..i) == name) then
				return "raid"..i
			end
		end 
	else 
		for i=1,GetNumGroupMembers()-1 do 
			if(UnitName("party"..i) == name) then
				return "party"..i
			end 
		end 
	end
	
	--[[if IsInGroup() then
		for i=1,GetNumGroupMembers() do
			if(UnitName("party"..i) == name) then
				return "party"..i
			end
		end
	end]]
	return nil
end

--[[
function GT:GetNumGroupMembers()
	if not self:IsGroup() then return 0 end
	if UnitInRaid("player") then
		return GetNumGroupMembers()
	else
		return GetNumSubgroupMembers() + 1 -- We need to add one because it won't count the player
	end
end
]]

function reSize(frame)
	local row = frame
	local playerw, lootw = row.player:GetWidth(), row.loot:GetWidth()
	local framewidth = (playerw > 0 and playerw+37 or -11)+lootw
	row:SetWidth(framewidth+8)
end

function FindFreeID()
	local i = 1
	for i = 1, config.maxItems do
		if not items[i].isshown then 
			return i
		end
	end
	return false
end

function QColor(row, quality)
	local r, g, b, hex = GetItemQualityColor(quality)
	row.border:SetVertexColor(r, g, b, .3)
	row.border:Show()
	row:SetBackdropBorderColor(r, g, b, 1)				
end

function CreateItem(type, ItemID, unit, icount, skip)
	local count, iName, iLink, iRarity, r, g, b, hex, iTexture
	local id = FindFreeID()
	if not id then debug("There is no free id") return end
	count = 0
	item = items[id]

	if type == "loot" then
		
		iName, iLink, iRarity, _, _, _, _, _, _, iTexture, _ = GetItemInfo(ItemID) 
		
		r, g, b, hex = GetItemQualityColor(iRarity)
		
	
		if unit == UnitName("player") then 
			count = GetItemCount(ItemID) or 0 
			local total 
			if skip then total = 0 else total = count + icount end
			if total > 1 then item.extra:SetText(total) else item.extra:SetText("") end
		else 
			item.extra:SetText("") 
		end
	elseif type == "money" then
		iName = ItemID
		iLink = nil
		iRarity = 1
		iTexture = "Interface\\MoneyFrame\\UI-GoldIcon"
		hex = " "
		item.extra:SetText("")
	end

	
	item.link = iLink
	unit_id = unitFromPlayerName(unit)

	local classTextColor
	if unit_id then 
		local _, class = UnitClass(unit_id) 
		classTextColor = RAID_CLASS_COLORS[class]
	end
	
	if unit then 
		item.player:SetText(unit)
		if classTextColor then item.player:SetTextColor(classTextColor.r, classTextColor.g, classTextColor.b) end
	else
		item.player:SetText("Unknown")
	end
	
	if icount and tonumber(icount) > 1 then 
		iName = icount.."x ".."|c"..hex..iName.."|r"
	else 
		if type ~= "money" then
			iName = "|c"..hex..iName.."|r"
		end
	end
	item.loot:SetText(iName)

	
	SetItemButtonTexture(item.button, iTexture)
	
	reSize(item)
	item:ClearAllPoints()
	if id > 0 then
		if items[id-1]  then
			item:SetPoint("LEFT", items[id-1], "LEFT", 0, -config.position.nextFrameOff)
		else
			if config.position.AnchorPoint == "LEFT" then
				item:SetPoint("LEFT", config.position.Anchor, "LEFT", config.position.Xoff, config.position.Yoff)
			else
				item:SetPoint("RIGHT", config.position.Anchor, "RIGHT", -config.position.Xoff, config.position.Yoff)
			end
		end
	end

	item:SetScale(config.scale)
	items[id] = item
	items[id].isshown=true
	
	
	UIFrameFadeIn(item, config.timers.fadeIn, 0, 1)
	CreateTimer(config.timers.fade, 1, id) 
end

function OnItemClick(button, item)
	if button == "LeftButton" and item.link then
		if ( IsControlKeyDown() ) then
			DressUpItemLink(item.link)
		elseif ( IsShiftKeyDown() ) then
			ChatEdit_InsertLink(item.link)
		else
			ShowUIPanel(ItemRefTooltip)
			if not ItemRefTooltip:IsVisible() then
				ItemRefTooltip:SetOwner(UIParent, "ANCHOR_PRESERVE")
			end
			ItemRefTooltip:SetHyperlink(item.link)
		end
	end
end

function BuildItem(id)
	local row = CreateFrame("Frame", "LM"..id, UIParent)
	local button = CreateFrame("Button", "LMButton"..id, row, "ItemButtonTemplate")
	button:EnableMouse(false)
	_G[button:GetName().."NormalTexture"]:SetWidth(66)
	_G[button:GetName().."NormalTexture"]:SetHeight(66)
	
	local overlay = CreateFrame("Button", "LMOverlay"..id, row)
	row.overlay = overlay
	
	row.player = row:CreateFontString("LM"..id.."Player", "ARTWORK", "GameFontNormalSmall")
	row.loot = row:CreateFontString("LM"..id.."Loot", "ARTWORK", "GameFontNormalSmall")
	row.extra = row:CreateFontString("LM"..id.."Extra", "ARTWORK", "GameFontNormalSmall")
		
	row:SetWidth(316)
	row:SetHeight(22)
	
	button:SetScale(0.55)
	button:ClearAllPoints()
	button:SetPoint("LEFT", row, "LEFT", 5, 0)
	button:Disable()
	
	overlay:RegisterForClicks("LeftButtonUp", "RightButtonUp")
	overlay:SetScript("OnEnter", function(self) 
		if row.link then 
			GameTooltip:SetOwner(row, "ANCHOR_TOPLEFT")
			GameTooltip:SetHyperlink(row.link) 
			if IsShiftKeyDown() then 
				GameTooltip_ShowCompareItem() 
			end 
			CursorUpdate(self); 
		end 
	end )
	overlay:SetScript("OnLeave", function() GameTooltip:Hide(); ResetCursor(); end)
	overlay:SetScript("OnClick", function(self,arg1) OnItemClick(arg1, row) end)
	overlay:SetScript("OnUpdate", function(self) 
		if IsShiftKeyDown() then 
			GameTooltip_ShowCompareItem() 
		end 
		CursorOnUpdate(self); 
	end)
	
	overlay:ClearAllPoints()
	overlay:SetAllPoints(row)
	
	row.player:SetHeight(16)
	row.loot:SetHeight(16)
	row.extra:SetHeight(16)
	
	row.player:ClearAllPoints()
	row.loot:ClearAllPoints()
	row.extra:ClearAllPoints()
	
	row.player:SetPoint("LEFT", button, "RIGHT", 3, 0)
	row.loot:SetPoint("LEFT", row.player, "RIGHT", 10, 0)
	row.extra:SetPoint("LEFT", row, "RIGHT", 2, 0)
	
	row.player:SetJustifyH("LEFT")
	row.loot:SetJustifyH("LEFT")
	row.extra:SetJustifyH("LEFT")
	
	button.wrapper = ItemWrapper(button, 9, 9, 20)
	
	button:Show()
	button:SetAlpha(1)
	
	Skin(row)
	
	row.button = button
	row.id = id
	
	row:Hide()
	
	return row
	
end

function ItemWrapper(button, w, h, edge, b_inset)
	local wrapper = button.wrapper or CreateFrame("Frame", button:GetName().."Wrapper", button)
	wrapper:SetWidth(button:GetWidth()+(w or 10))
	wrapper:SetHeight(button:GetHeight()+(h or 10))
	wrapper:ClearAllPoints()
	wrapper:SetPoint("CENTER", button, "CENTER")
	Skin(wrapper)
	if edge then
		local backdrop = wrapper:GetBackdrop()
		backdrop.edgesize = edge
		wrapper:SetBackdrop(backdrop)
	end
	
	wrapper:SetBackdropColor(1, 1, 1, 0)
	wrapper:SetBackdropBorderColor(.7, .7, .7, 1)
	wrapper:Show()
	return wrapper
end

function Skin(frame)
	if not frame then return end
	
	frame:SetBackdrop(backdrop)
	frame:SetBackdropBorderColor(sdb.BackdropBorder.r, sdb.BackdropBorder.g, sdb.BackdropBorder.b, sdb.BackdropBorder.a)
	frame:SetBackdropColor(sdb.Backdrop.r, sdb.Backdrop.g, sdb.Backdrop.b, sdb.Backdrop.a)

	if not frame.fade then frame.fade = frame:CreateTexture(nil, "BORDER") end
	frame.fade:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")

	if sdb.FadeHeight.enable and sdb.FadeHeight.force then 
		fh = sdb.FadeHeight.value <= math.ceil(frame:GetHeight()) and sdb.FadeHeight.value
	end 

	frame.fade:SetPoint("TOPLEFT", frame, "TOPLEFT", 4, -4)
	
	if fh then 
		frame.fade:SetPoint("BOTTOMRIGHT", frame, "TOPRIGHT", -4, -fh)
	else 
		frame.fade:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -4, 4) 
	end

	frame.fade:SetBlendMode("ADD")
	frame.fade:SetGradientAlpha(unpack(sdb.Gradient and gradientOn or gradientOff)) 
end


--LOOT_ITEM_SELF = "You receive loot: %s.";
--LOOT_ITEM = "%s receives loot: %s.";
--LOOT_ITEM_CREATED_SELF = "You create: %s.";
--LOOT_ITEM_PUSHED_SELF = "You receive item: %s.";

local LOOT_ITEM_SELF_REG = string.gsub(LOOT_ITEM_SELF, " %%s.", "")
local LOOT_ITEM_REG = string.gsub(LOOT_ITEM, "%%s ", "")
local LOOT_ITEM_REG = string.gsub(LOOT_ITEM_REG, " %%s.", "")
local LOOT_ITEM_CREATED_REG = string.gsub(LOOT_ITEM_CREATED_SELF, " %%s.", "")
local LOOT_ITEM_PUSHED_REG = string.gsub(LOOT_ITEM_PUSHED_SELF, " %%s.", "")


local find = string.find
function LM:CHAT_MSG_LOOT(event, msg)
	local skipTotal = false
	local sPlayer, sLink, itemId, iCount = nil, nil, nil, nil

	if find(msg, LOOT_ITEM_SELF_REG) then 
		sLink, iCount = deformat(msg, LOOT_ITEM_SELF_MULTIPLE) 
		sPlayer = UnitName("player")
		if sLink then 
			itemId=select(3, find(sLink, "item:(%d+):"))
		else
			sLink = deformat(msg, LOOT_ITEM_SELF) 
			itemId=select(3, find(sLink, "item:(%d+):"))
			iCount = 1
		end
	elseif find(msg, LOOT_ITEM_REG) then
		sPlayer, sLink, iCount = deformat(msg, LOOT_ITEM_MULTIPLE) 
		if sLink then 
			itemId=select(3, find(sLink, "item:(%d+):"))
		else
			sPlayer, sLink = deformat(msg, LOOT_ITEM) 
			itemId=select(3, find(sLink, "item:(%d+):"))
			iCount = 1
		end
	elseif find(msg, LOOT_ITEM_CREATED_REG) then
		skipTotal = true
		sLink, iCount = deformat(msg, LOOT_ITEM_CREATED_SELF_MULTIPLE) 
		sPlayer = UnitName("player")
		if sLink then 
			itemId=select(3, find(sLink, "item:(%d+):"))
		else
			sLink = deformat(msg, LOOT_ITEM_CREATED_SELF) 
			itemId=select(3, find(sLink, "item:(%d+):"))
			iCount = 1
		end
	elseif find(msg, LOOT_ITEM_PUSHED_REG) then
		skipTotal = true
		sLink, iCount = deformat(msg, LOOT_ITEM_PUSHED_SELF_MULTIPLE) 
		sPlayer = UnitName("player")
		if sLink then 
			itemId=select(3, find(sLink, "item:(%d+):"))
		else
			sLink = deformat(msg, LOOT_ITEM_PUSHED_SELF) 
			itemId=select(3, find(sLink, "item:(%d+):"))
			iCount = 1
		end
	end
	
	
	if sPlayer and itemId then 
		local Rarity = select(3, GetItemInfo(itemId))
		if (Rarity < config.Rarity and sPlayer ~= UnitName("player")) or (Rarity < config.selfRarity and sPlayer == UnitName("player")) 
		then 
		else 
			CreateItem("loot", itemId, sPlayer, iCount, skipTotal) 
		end
	end
	
end

local GOLD_REG = "(%d+) "..string.gsub(GOLD_AMOUNT, "%%d ", "")
local SILVER_REG = "(%d+) "..string.gsub(SILVER_AMOUNT, "%%d ", "")
local COPPER_REG = "(%d+) "..string.gsub(COPPER_AMOUNT, "%%d ", "")

function LM:CHAT_MSG_MONEY(event, msg)
	local gold = string.match(msg, GOLD_REG)
	local silver = string.match(msg, SILVER_REG)
	local copper = string.match(msg, COPPER_REG)
	local amount = "|cffffffff"..(gold or 0).."|rg ".."|cffffffff"..(silver or 0).."|rs ".."|cffffffff"..(copper or 0).."|rc"
	CreateItem("money", amount, " ", 0, false)
end

function LM:ADDON_LOADED(event, name)
	if name ~= "LootMon" then return end
	
	if not LootMonDB then 
		LootMonDB = LootMonDB_default 
		print ("wtf")
	end
	config = LootMonDB
	createConfigFrame() 
	for i = 1, LootMonDB.maxItems do
		if not items[i] then 
			items[i] = BuildItem(i)
			items[i].isShown = false
		end
	end
end

--[[do
	
end]]